@@ -1,6 +1,6 @@
 """This module provides the Base class for PSDs"""
-import pylab as plt
-import pylab
+import logging
+
 import numpy
 
 from spectrum.tools import nextpow2
@@ -9,8 +9,7 @@ from spectrum.window import window_names
 from spectrum import tools
 
 
-__all__ = ["Spectrum", "FourierSpectrum", "ParametricSpectrum"]
-debug = False
+__all__ = ["Spectrum", "FourierSpectrum", "ParametricSpectrum", "Range"]
 
 
 class Range(object):
@@ -96,7 +95,7 @@ class Range(object):
     def _setsampling(self, sampling):
         self.__sampling = sampling
         self.__df = self.__sampling/float(self.__N)
-    sampling = property(fget=_getsampling, fset=_setsampling, 
+    sampling = property(fget=_getsampling, fset=_setsampling,
         doc="""Getter/Setter of the sampling frequency. If changed, :attr:`df` is updated.""")
 
     def centerdc_gen(self):
@@ -104,7 +103,7 @@ class Range(object):
 
         ::
 
-            >>> print list(Range(8).centerdc_gen())
+            >>> print(list(Range(8).centerdc_gen()))
             [-0.5, -0.375, -0.25, -0.125, 0.0, 0.125, 0.25, 0.375]
 
         """
@@ -116,7 +115,7 @@ class Range(object):
 
         ::
 
-            >>> print list(Range(8).centerdc_gen())
+            >>> print(list(Range(8).centerdc_gen()))
             [0, 0.125, 0.25, 0.375, 0.5, 0.625, 0.75, 0.875]
 
         """
@@ -131,9 +130,9 @@ class Range(object):
 
         ::
 
-            >>> print list(Range(8).onesided())
+            >>> print(list(Range(8).onesided()))
             [0.0, 0.125, 0.25, 0.375, 0.5]
-            >>> print list(Range(9).onesided())
+            >>> print(list(Range(9).onesided()))
             [0.0, 0.1111, 0.2222, 0.3333, 0.4444]
 
         """
@@ -216,7 +215,7 @@ class Spectrum(object):
     At any time, you can get general information about the Spectrum instance::
 
         >>> p = Spectrum(marple_data)
-        >>> print p
+        >>> print(p)
         Spectrum summary
             Data length is 64
             PSD not yet computed
@@ -240,7 +239,7 @@ class Spectrum(object):
         From the input parameters, the following attributes are set:
 
           * :attr:`data` (updates :attr:`N`, :attr:`df`, :attr:`datatype`)
-          * :attr:`data_y`
+          * :attr:`data_y` used for cross PSD only (correlogram)
           * :attr:`detrend`
           * :attr:`sampling` (updates :attr:`df`)
           * :attr:`scale_by_freq`
@@ -298,15 +297,18 @@ class Spectrum(object):
         self.__method = method
     method = property(fget=_getMethod, fset=_setMethod)
 
-    def __call__(self, *args, **kargs):
-        print("""To be use with care. THis function is there just to help, it
-            does not populate the proper attribute except psd.""")
+    """def __call__(self, *args, **kargs):
+        # To be use with care. THis function is there just to help, it
+        #    does not populate the proper attribute except psd.
         if self.method is not None:
             res = self.method(self.data, *args, **kargs)
             self.psd = res[0]
         #return res
-
-    def run(self):
+    """
+    def run(self, *args, **kargs):
+        # Kept for back compatibility
+        # e.g. used in this external notebook:
+        # http://nbviewer.jupyter.org/gist/juhasch/5182528
         self()
 
     def _getDetrend(self):
@@ -328,7 +330,7 @@ class Spectrum(object):
 
     def _get_range(self):
         return self._range
-    range = property(fget=_get_range, 
+    range = property(fget=_get_range,
             doc="""Read only attribute to a :class:`Range` object.""")
 
     def _getScale(self):
@@ -345,18 +347,18 @@ class Spectrum(object):
         return self.__NFFT
     def _setNFFT(self, NFFT):#if NFFT is changed, we need to redo the padding
         if self.__NFFT == NFFT and self.__NFFT is not None:
-            #print 'NFFT is the same, nothing to do'
+            logging.debug('NFFT is the same, nothing to do')
             return
         new_nfft = None
         if NFFT == 'nextpow2':
-            #print 'NFFT is based on nextpow2:',
             n = nextpow2(self.data.size)
-            new_nfft = int(pow(2,n))
+            new_nfft = int(pow(2, n))
+            logging.debug('NFFT is based on nextpow2: %s' % new_nfft)
         elif NFFT is None:
-            #print 'NFFT set to data length',
+            logging.debug('NFFT set to data length')
             new_nfft = self.N
         elif isinstance(NFFT, int):
-            #print 'NNFT set  manually to',
+            logging.debug('NNFT set  manually to {}'.format(NFFT))
             assert NFFT > 0, 'NFFT must be a positive integer'
             new_nfft = NFFT
         else:
@@ -409,7 +411,7 @@ class Spectrum(object):
             newpsd = self.get_converted_psd(sides)
             self.__psd = newpsd
         self.__sides = sides
-        #print '------------> %s %s' % (self.__sides, sides)
+        logging.debug('------------> %s %s' % (self.__sides, sides))
         # we set the PSD by hand, so we can consider that PSD is up-to-date
         self.modified = False
     _doc_sides = """Getter/Setter to the :attr:`sides` attributes.
@@ -450,10 +452,9 @@ class Spectrum(object):
 
     def _getPSD(self):
         if self.__psd is None:
-            print('PSD not yet computed. call the object to estimate the PSD.')
-
-        else:
-            return self.__psd
+            logging.debug('Computing PSD.')
+            self()
+        return self.__psd
     def _setPSD(self, psd):
         # Reset the sides attribute depending on the datatype
         # if a user sets the PSD manually, the only check available is that
@@ -503,14 +504,14 @@ class Spectrum(object):
         self.__sampling = sampling
         self.__df = self.__sampling / float(self.__N)
         self.modified = True
-    sampling = property(fget=_getSampling, fset=_setSampling, doc="""Getter/Setter to sampling frequency
-        Updates the :attr:`df` automatically.""")
+    sampling = property(fget=_getSampling, fset=_setSampling,
+        doc="""Getter/Setter to sampling frequency. Updates the :attr:`df` automatically.""")
 
     #the frequency resolution. Read only.
     def _getdf(self):
         return self._range.df
     df = property(fget=_getdf, doc="""Getter to step frequency. This attribute
-    is updated as soon as :attr:`data` or :attr:`sampling` is changed""")
+ is updated as soon as :attr:`data` or :attr:`sampling` is changed""")
 
     def _getdatatype(self):
         return self.__datatype
@@ -521,7 +522,7 @@ class Spectrum(object):
 
     def scale(self):
         if self.scale_by_freq is True:
-            self.psd *= 2*plt.pi/self.df
+            self.psd *= 2*numpy.pi/self.df
 
     def frequencies(self, sides=None):
 
@@ -549,7 +550,6 @@ class Spectrum(object):
 
             from spectrum import *
             p = pcovar(marple_data, 15)
-            p()
             centerdc_psd = p.get_converted_psd('centerdc')
 
         .. note:: this function does not change the object, in particular, it
@@ -566,9 +566,9 @@ class Spectrum(object):
                 "complex datatype so sides cannot be onesided."
 
         if self.sides == 'onesided':
-            if debug: print('Current sides is onesided')
+            logging.debug('Current sides is onesided')
             if sides == 'twosided':
-                if debug: print('--->Converting to twosided')
+                logging.debug('--->Converting to twosided')
                 # here we divide everything by 2 to get the twosided versin
                 N = self.NFFT
                 newpsd = numpy.concatenate((self.psd[0:-1]/2., list(reversed(self.psd[0:-1]/2.))))
@@ -576,18 +576,17 @@ class Spectrum(object):
                 newpsd[-1] = self.psd[-1]
                 newpsd[0] *= 2.
             elif sides == 'centerdc':
-                print('--->Converting to centerdc')
+                logging.debug('--->Converting to centerdc')
                 newpsd = numpy.concatenate((self.psd[-1:0:-1]/2., self.psd[0:-1]/2.))
                 # so we need to multiply by 2 the 0 and F2/2 frequencies
-                
+
                 newpsd[int(self.NFFT/2)] *= 2.
                 newpsd[0] *= 2.
             self.NFFT = len(newpsd)
-
         elif self.sides == 'twosided':
-            print('Current sides is twosided')
+            logging.debug('Current sides is twosided')
             if sides == 'onesided':
-                print('--->Converting to onesided')
+                logging.debug('--->Converting to onesided')
                 N = self.NFFT
                 newpsd = numpy.array(self.psd[0:int(N/2)+1]*2)
                 newpsd[0] /= 2
@@ -596,9 +595,9 @@ class Spectrum(object):
                 newpsd = tools.twosided_2_centerdc(self.psd)
             self.NFFT = len(self.psd)
         elif self.sides == 'centerdc': # same as twosided to onesided
-            print('Current sides is centerdc')
+            logging.debug('Current sides is centerdc')
             if sides == 'onesided':
-                print('--->Converting to onesided')
+                logging.debug('--->Converting to onesided')
                 N = self.NFFT
                 newpsd = numpy.array(list(reversed(self.psd[0:int(N/2)+1]*2)))
                 newpsd[0] = self.psd[int(N/2)]
@@ -628,13 +627,14 @@ class Spectrum(object):
 
             from spectrum import *
             p = Periodogram(marple_data)
-            p()    # runs the psd estimate
             p.plot(norm=True, marker='o')
 
         """
+        import pylab
         #First, check that psd attribute is up-to-date
         if self.modified is True:
-            raise errors.SpectrumModifiedError
+            # just to get the PSD to be recomputed if needed
+            self.psd
 
         # and that it has been computed
         if self.__psd is None:
@@ -658,6 +658,7 @@ class Spectrum(object):
             if self.datatype == 'complex':
                 assert sides != 'onesided'
 
+            logging.debug("sides is different from the one provided. Converting PSD")
             frequencies = self.frequencies(sides=sides)
             psd = self.get_converted_psd(sides)
 
@@ -667,8 +668,8 @@ class Spectrum(object):
         from pylab import ylim as plt_ylim
 
         if 'ax' in list(kargs.keys()):
-            save_ax = plt.gca()
-            plt.sca(kargs['ax'])
+            save_ax = pylab.gca()
+            pylab.sca(kargs['ax'])
             rollback = True
             del kargs['ax']
         else:
@@ -679,21 +680,26 @@ class Spectrum(object):
         else:
             pylab.plot(frequencies, 10*pylab.log10(psd),**kargs)
 
-        plt.xlabel('Frequency')
-        plt.ylabel('Power (dB)')
+        pylab.xlabel('Frequency')
+        pylab.ylabel('Power (dB)')
         pylab.grid(True)
+
         if ylim:
             plt_ylim(ylim)
+
         if sides == 'onesided':
-            pylab.xlim(0,self.sampling/2.)
+            pylab.xlim(0, self.sampling/2.)
         elif sides == 'twosided':
             pylab.xlim(0, self.sampling)
         elif sides == 'centerdc':
             pylab.xlim(-self.sampling/2., self.sampling/2.)
+
         if filename:
             pylab.savefig(filename)
+
         if rollback:
-            plt.sca(save_ax)
+            pylab.sca(save_ax)
+
         del psd, frequencies #is it needed?
 
     def power(self):
@@ -714,7 +720,7 @@ class Spectrum(object):
         if self.scale_by_freq == False:
             return sum(self.psd) * len(self.psd)
         else:
-            return sum(self.psd) * self.df/(2.*plt.pi)
+            return sum(self.psd) * self.df/(2.*numpy.pi)
 
     def _str_title(self):
         return "Spectrum summary\n"
@@ -770,13 +776,13 @@ class ParametricSpectrum(Spectrum):
         #s.plot(sides='twosided')
 
     """
-    def __init__(self, data, sampling=1., ar_order=None, ma_order=None, 
+    def __init__(self, data, sampling=1., ar_order=None, ma_order=None,
             lag=-1, NFFT=None, detrend=None, scale_by_freq=True):
         """**Constructor**
 
         See the class documentation for the parameters.
 
-        .. rubric:: Additional attributes to those inherited 
+        .. rubric:: Additional attributes to those inherited
             from :class:`Spectrum`:
 
         * :attr:`ar_order`, the ar order of the PSD estimates
@@ -872,78 +878,6 @@ class ParametricSpectrum(Spectrum):
     def __str__(self):
         return super(ParametricSpectrum, self).__str__()
 
-    """
-    def pma(self):
-        from arma import ma, arma2psd
-        mav, rho = ma(self.data, self.ma_order, self.ar_order)
-        self.ma = mav
-        self.rho = rho
-        psd = arma2psd(A=None, B=self.ma, rho=self.rho,
-                      T=self.sampling, NFFT=self.NFFT)
-        #self.psd = psd
-        if self.datatype == 'real':
-            newpsd  = psd[int(self.NFFT/2):]*2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[0])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-        self.scale()
-
-    def parma(self):
-        from arma import arma_estimate, arma2psd
-        ar, ma, rho = arma_estimate(self.data, self.ar_order, self.ma_order, self.lag)
-        self.ma = ma
-        self.ar = ar
-        self.rho = rho
-
-        psd = arma2psd(A=self.ar, B=self.ma, rho=self.rho,
-                      T=self.sampling, NFFT=self.NFFT)
-        #self.psd = psd
-        if self.datatype == 'real':
-            newpsd  = psd[0:int(self.NFFT/2)]*2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[-1])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-        self.scale()
-        #self.modified = False
-    """
-    """
-    def pburg(self):
-        from arma import arma2psd
-        from burg import arburg
-        ar, rho, ref = arburg(self.data, self.ar_order, criteria=None)
-        self.ar = ar
-        self.rho = rho
-        self.reflection = ref
-        psd = arma2psd(A=self.ar, B=self.ma, rho=self.rho,
-                      T=self.sampling, NFFT=self.NFFT)
-        #self.psd = psd
-        if self.datatype == 'real':
-            newpsd  = psd[0:iint(self.NFFT/2)]*2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[-1])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-        self.scale()
-    """
-
-    """def minvar(self):
-        from minvar import minvar
-        psd = minvar(self.data, self.ar_order, sampling=self.sampling,
-                     NFFT=self.NFFT)
-        if self.datatype == 'real':
-            newpsd  = psd[0:int(self.NFFT/2)]*2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[-1])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-        self.scale()
-    """
 
 
 class FourierSpectrum(Spectrum):
@@ -1063,46 +997,3 @@ class FourierSpectrum(Spectrum):
         self.psd = psd
 
 
-    def _correlogram(self):
-        """An alias to :class:`~spectrum.correlog.pcorrelogram`
-
-        The parameters are extracted from the attributes. Relevant attributes
-        ares :attr:`window`, attr:`sampling`, attr:`NFFT`, attr:`scale_by_freq`,
-        :attr:`detrend`.
-
-        .. plot::
-            :width: 80%
-            :include-source:
-
-            from spectrum import datasets
-            from spectrum import FourierSpectrum
-            s = FourierSpectrum(datasets.data_cosine(), sampling=1024, NFFT=512, lag=32)
-            s._correlogram()
-            s.plot()
-        """
-        from spectrum.correlog import CORRELOGRAMPSD
-        psd = CORRELOGRAMPSD(self.data, self.data_y,
-                             lag=self.lag,
-                             window=self.window,
-                             NFFT=self.NFFT,
-                             #   scale_by_freq=self.scale_by_freq,
-                             )
-        if self.datatype == 'real':
-            newpsd  = psd[0:int(self.NFFT/2)]*2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[-1])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-
-    """
-    def welch(self):
-        raise NotImplementedError
-
-    def daniell(self):
-        raise NotImplementedError
-
-
-    def bartlett(self):
-        raise NotImplementedError
-    """
